@@ -3,7 +3,7 @@
    Copyright (C) 2020-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 1.1.0 (2021-07-27)
+   Version: 1.6.0 (2021-09-17)
    Website: http://www.gingerblue.org/
 
  */
@@ -12,13 +12,16 @@
 #include <gtk/gtk.h>
 #include <gst/gst.h>
 #include "gingerblue.h"
+#include "gingerblue-config.h"
+#include "gingerblue-main.h"
 #include "gingerblue-main-loop.h"
+#include "gingerblue-studio-config.h"
 
 int main_app (gint argc, gchar *argv[]) {
 	GingerblueData *gingerblue_config;
         GtkWindow *gingerblue_window;
 	gtk_init (&argc, &argv);
-        gingerblue_config = main_config ("studios.gingerblue.org");
+        gingerblue_config = main_config (gingerblue_window, "studios.gingerblue.org");
 	gingerblue_window = gingerblue_main_loop (gingerblue_config);
 	gtk_widget_show_all (gingerblue_window);
 	gst_init(&argc, &argc);
