@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 1.1.0 (2021-07-27)
+   Version: 1.6.0 (2021-09-17)
    Website: http://www.gingerblue.org/
    
 */
@@ -18,33 +18,31 @@
 
 GingerblueData *
 gb_file_parse_volume (GingerblueData *data, xmlDocPtr doc, xmlNodePtr cur) {
-	xmlNodePtr sub;
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (doc != NULL);
-	g_return_if_fail (cur != NULL);
-	data->version = (gchar *)xmlGetProp (cur, (const xmlChar *)"version");
-	data->volume = (gchar *)xmlGetProp (cur, (const xmlChar *)"volume");  
+        GingerblueData *gbdata = (GingerblueData *)data;
+        xmlNodePtr sub;
+	gbdata->version = (gchar *)xmlGetProp (cur, (const xmlChar *)"version");
+	gbdata->volume = (gchar *)xmlGetProp (cur, (const xmlChar *)"volume");
 	sub = cur->xmlChildrenNode;
 	while (sub != NULL) {
 		if ((!xmlStrcmp
 		     (sub->name, (const xmlChar *) "line"))) {
-			data->line = (gchar *) xmlNodeListGetString(doc, sub->xmlChildrenNode, 1);
+			gbdata->line = (gchar *) xmlNodeListGetString(doc, sub->xmlChildrenNode, 1);
 		}
 		if ((!xmlStrcmp
 		     (sub->name, (const xmlChar *) "musician"))) {
-			data->musician = (gchar *) xmlNodeListGetString(doc, sub->xmlChildrenNode, 1);
+			gbdata->musician = (gchar *) xmlNodeListGetString(doc, sub->xmlChildrenNode, 1);
 		}
 		if ((!xmlStrcmp
 		     (sub->name, (const xmlChar *) "musical_instrument"))) {
-			data->musical_instrument = (gchar *) xmlNodeListGetString(doc, sub->xmlChildrenNode, 1);
+			gbdata->musical_instrument = (gchar *) xmlNodeListGetString(doc, sub->xmlChildrenNode, 1);
 		}
 		if ((!xmlStrcmp
 		     (sub->name, (const xmlChar *) "volume"))) {
-			data->volume = (gchar *) xmlNodeListGetString(doc, sub->xmlChildrenNode, 1);
+			gbdata->volume = (gchar *) xmlNodeListGetString(doc, sub->xmlChildrenNode, 1);
 		}
 		sub = sub->next;
 	}
-	return (GingerblueData *)data;
+	return (GingerblueData *)gbdata;
 }
 
 GingerblueData *
