@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 1.1.0 (2021-07-27)
+   Version: 1.5.0 (2021-09-16)
    Website: http://www.gingerblue.org/
 
  */
@@ -22,7 +22,9 @@
 #include <string.h>
 #include "gingerblue.h"
 #include "gingerblue-chord.h"
+#include "gingerblue-config.h"
 #include "gingerblue-main.h"
+#include "gingerblue-main-loop.h"
 #include "gingerblue-record.h"
 #include "gingerblue-studio-config.h"
 #include "gingerblue-studio-location.h"
@@ -85,10 +87,24 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	GstElement *src, *conv, *enc, *muxer, *sink, *recorder;
 	gchar *filename = NULL;
 	GDateTime *datestamp = g_date_time_new_now_utc ();
+	GstElementFactory *factory;
+
 	gst_element_send_event(recorder, gst_event_new_eos());
 
 	recorder = gst_pipeline_new("record_pipe");
 
+	/*
+	  FIXME: Line #59 from https://github.com/GStreamer/gst-plugins-base/blob/master/tools/gst-device-monitor.c
+	  element = gst_device_create_element (device, NULL);
+	  if (!element)
+	  return NULL;
+	  factory = gst_element_get_factory (element);
+	  if (!factory) {
+	  gst_object_unref (element);
+	  return NULL;
+	  }
+	  src = gst_element_factory_create(factory, NULL);
+	*/
 	src = gst_element_factory_make("autoaudiosrc", "auto_source");
 	conv = gst_element_factory_make("audioconvert", "convert");
 	enc = gst_element_factory_make("vorbisenc", "vorbis_enc");
