@@ -3,7 +3,7 @@
    Copyright (C) 2020-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 1.1.0 (2021-07-27)
+   Version: 1.5.0 (2021-09-16)
    Website: http://www.gingerblue.org/
 
  */
@@ -84,13 +84,13 @@ int main_studio_stream (gchar *location_data, gpointer *studio_city) {
 		FILE *studio_stream_fp = fopen((char *)gtk_entry_get_text(GTK_ENTRY(recording_entry)), "r+");
 		flock(studio_stream_fp, LOCK_SH);
 		while (1) {
-			g_printf(stderr, "FILENAME %s\n", (char *)gtk_entry_get_text(GTK_ENTRY(recording_entry)));
+			g_print(stderr, "FILENAME %s\n", (char *)gtk_entry_get_text(GTK_ENTRY(recording_entry)));
 			total = fseek((FILE *)studio_stream_fp, 0, SEEK_CUR);
 			read = fread(buff, 1, sizeof(buff), studio_stream_fp);
 			total = total + read;
-			g_printf(stderr, "%li of %li\n", read, total);
+			g_print(stderr, "%li of %li\n", read, total);
 			if (read > 0) {
-			        g_printf(stderr, "%li\n", read);
+			        g_print(stderr, "%li\n", read);
 			        ret = shout_send(shout, buff, read);
 				if (ret != SHOUTERR_SUCCESS) {
 				        printf("DEBUG: Send error: %s\n", shout_get_error(shout));
